<?php
namespace Teknisa\CRM\Controller;

use Teknisa\CRM\Controller\TeknisaCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request\Row;
use Teknisa\CRM\Service\crm00002006FilaContatoService;

class crm00002006FilaContatoController extends TeknisaCrud {
    protected $dataSourceName = 'filacontato_agendatarefas';
    protected $primaryKey = 'NRSEQFILACONTA';
    //protected $CDCONTADOR = 'FILACONTATO';
    protected $filaContato;
    
    protected $environment;

    public function __construct($crudService, $parameterBag, $environment, crm00002006FilaContatoService $filaContatoService, $controlerNovaTarefa, $emailService){
        parent::__construct($crudService, $parameterBag);
        $this->environment = $environment;
        $this->filaContatoService = $filaContatoService;
        $this->controlerNovaTarefa = $controlerNovaTarefa;
        $this->emailService = $emailService;
    }

    public function save(DTO\Request $request, DTO\Response $response) {
        foreach($request->getDataSet()->getRows() as $row) {
            if(!array_key_exists('DSDETEFILACONTA', $row)) $row['DSDETEFILACONTA'] = null;
            if(!array_key_exists('NRRELACIONAPARC', $row)) $row['NRRELACIONAPARC'] = null;
            if(!array_key_exists('IDORIGFILACONTA', $row)) $row['IDORIGFILACONTA'] = 'M';
            $row["CDFILIAL"] = $this->environment->getCdFilial();
            if($row["__is_new"]) {
                $row['__new_code_pk'] = "FILACONTATO";
                $row['__table_pk'] = "NRSEQFILACONTA";
                $row['__cast_number'] = true;
                $row['__new_code_length'] = 20;
                $row['__columns_to_return'] = array("NRSEQFILACONTA");
            }
        }

    	parent::save($request, $response);
        if($row["__is_new"]) {
            $response->addDataset(new DataSet('DADOS', $this->crudService->getColumnsToReturn()));
        }
      
    }
    
    /**
     * Insere uma nova tarefa após uma evolução.
     * 
     * @param DTO\Request\Row $request
     */
    public function inserirTarefa(DTO\Request\Row $request, DTO\Response $response) {
        
        $row = $request->getRow();
        $nrorg = $this->environment->getNrOrg();
        $params = array(
            "DSFILACONTATO"             => $row["DSFILACONTATO"],
            "DTPLANFILACONTA"           => $row["DTPLANFILACONTA"],
            "CDOPERREAL"                => $row["CDOPEREVOL"],
            "NRORG"                     => $nrorg,
            "CRM_NRORGTRAB"             => $row["CRM_NRORGTRAB"],
            "CDOPERINCLUSAO"            => $row["CDOPEREVOL"],
            "NRPARCNEGOCIO"             => $row["NRPARCNEGOCIO"],
            "NRCONTATO"                 => $row["NRCONTATO"],
            "NRSEQCONTATO"              => $row["NRSEQCONTATO"],
            "NRSEQCLASSIFICATAREFA"     => empty($row["NRSEQCLASSIFICATAREFA"]) ? '' : $row["NRSEQCLASSIFICATAREFA"],
            "NRPRIORFILACONT"           => empty($row["NRPRIORFILACONT"]) ? '' : $row["NRPRIORFILACONT"],
            "NRSEQCAMPANHA"             => empty($row["NRSEQCAMPANHA"]) ? '' : $row["NRSEQCAMPANHA"],
            "NRSEQINTERLOCUTOR"         => empty($row['NRSEQINTERLOCUTOR']) ? '' : $row['NRSEQINTERLOCUTOR'],
            "DSEMAILTAREFA"             => empty($row['EMAILINTERLOC']) ? '' : $row['EMAILINTERLOC'],
            "DSTELEFONETAREFA"          => empty($row['NRTELEFONE1']) ? '' : $row['NRTELEFONE1'],
        );
        
        if($row["CDOPERINCLUSAO"] != $row["CDOPERREAL"] && !empty($row["DSEMAILOPER"])){
        
            $paramsEmail = array(
                "TIPO"                  => "",
                "NMOPERREAL"            => empty($row["NMOPERADORREAL"]) ? '' : $row["NMOPERADORREAL"],
                "OPERADORDOLOGADO"      => empty($row["NMOPERADOR"]) ? '' : $row["NMOPERADOR"],
                "DSTIPO"                => null,
                "DESCRICAO"             => null,
                "NRSEQCONTATO"          => null,
                "DSFILACONTATO"         => empty($row["DSFILACONTATO"]) ? '' : $row["DSFILACONTATO"],
                "NMPARCNEGOCIO"         => empty($row["NMPARCNEGOCIO"]) ? '' : $row["NMPARCNEGOCIO"],
                "DTPLANFILACONTA"       => empty($row["DTPLANFILACONTA"]) ? '' : $row["DTPLANFILACONTA"],
                "DTVENCFILACONTA"       => null,
                "DSCLASSIFICATAREFA"    => null,
                "DSDETEFILACONTA"       => null,
                "DSEMAILOPER"           => empty($row["DSEMAILOPER"]) ? '' : $row["DSEMAILOPER"]
                );
            
            $this->controlerNovaTarefa->enviaEmailTarefa($paramsEmail);
        }
        
        $nrseqfilaconta = $this->filaContatoService->inserirTarefa($params);
        $this->filaContatoService->updateEvol($row, $nrseqfilaconta);
        $response->addDataset(new DataSet('DADOS', array("NRSEQFILACONTA" => $nrseqfilaconta)));
        
    }
    
    
     public function enviaEmailTarefa($row){
         
        //Trata os dados
        $row["NUMEROTICKETRELACIONADO"] = null;
        $row["DSTIPO"] = '.';
        
        if($row["TIPO"] == "PARCEIRO"){
            $row["DSTIPO"] = ' relacionada ao Parceiro' ;
            $row["NUMEROTICKETRELACIONADO"] = $row["DESCRICAO"];
            
        }else if($row["TIPO"] == "OPORTUNIDADE"){
            $row["DSTIPO"] = ' relacionada à Oportunidade';
            $row["NUMEROTICKETRELACIONADO"] = $row["DESCRICAO"];
            
        }else if($row["TIPO"] == "CHAMADO"){
            $row["DSTIPO"] = ' relacionada ao Ticket' ;
            $row["NUMEROTICKETRELACIONADO"] = ' #'.$row["NRSEQCONTATO"].' - '.$row["DESCRICAO"] ;
        }
        
        if(empty($row["NMOPERREAL"])) $row["NMOPERREAL"]  = 'Sem Operador';
        if(empty($row["OPERADORDOLOGADO"])) $row["OPERADORDOLOGADO"]  = 'Sem Operador';
        if(empty($row["DSTIPO"])) $row["DSTIPO"]  = '';
        if(empty($row["DESCRICAO"])) $row["DESCRICAO"]  = 'Sem Relacionamento';
        if(empty($row["NRSEQCONTATO"])) $row["NRSEQCONTATO"]  = 'Sem Relacionamento';
        if(empty($row["DSFILACONTATO"])) $row["DSFILACONTATO"]  = 'Sem Assunto ';
        if(empty($row["NMPARCNEGOCIO"])) $row["NMPARCNEGOCIO"]  = 'Sem Parceiro';
        if(empty($row["DTPLANFILACONTA"])) $row["DTPLANFILACONTA"]  = 'Sem Data da Tarefa';
        if(empty($row["DTVENCFILACONTA"]) && empty($row["DTREALFILACONTA"])) $row["DTVENCFILACONTA"]  = 'Sem Data de Vencimento';
        if(empty($row["DSCLASSIFICATAREFA"])) $row["DSCLASSIFICATAREFA"]  = 'Sem Classificação';
        if(empty($row["DSDETEFILACONTA"])) $row["DSDETEFILACONTA"]  = 'Sem Descrição';
        
        //Dados de envio do email
        $parametrosEmail = array(
            'to' => array( 
                'email' => $row["DSEMAILOPER"],
                'name'  => $row["NMOPERREAL"],
            ),
            'subject' => 'CRM - Nova Tarefa',
            'from' => 'Equipe CRM'
        );
        //Monta o template
        $template = '<table border="0" width="100%" cellpadding="0" cellspacing="0" bgcolor="eeeeee" style="background-color: #eeeeee;"> <tbody> <tr> <td> <table border="0" align="center" width="590" cellpadding="0" cellspacing="0" bgcolor="0274BA" class="container590" style="background-color: #0274ba; text-align: center;"> <tbody> <tr> <td> <table border="0" align="center" width="540" cellpadding="0" cellspacing="0" class="container580"> <tbody> <tr> <td align="center" valign="middle"> <table border="0" align="middle" cellpadding="0" cellspacing="0" style="border-collapse:collapse; mso-table-lspace:0pt; mso-table-rspace:0pt;" class=""> <tbody> <tr> <td align="center" valign="middle"> <p style="color: #ffffff; font-size: 25px; padding:20px; font-family: " Questrial ", Helvetica, sans-serif; line-height: 25px; padding-top:45px;">NOTIFICAÇÃO DE NOVA TAREFA</p> </td> </tr> </tbody> </table> </td> </tr> </tbody> </table> </td> </tr> </tbody> </table> </td> </tr> </tbody> </table> <table border="0" width="100%" cellpadding="0" cellspacing="0" bgcolor="eeeeee"> <tbody> <tr> <td align="center"> <table border="0" align="center" width="590" cellpadding="0" cellspacing="0" bgcolor="ffffff" class="container590 bg_color"> <tbody> <tr> <td> <table border="0" align="center" width="540" cellpadding="0" cellspacing="0" class="container580"> <tbody> <tr> <td align="left" style="color: #39434b; font-size: 20px; font-family: " Montserrat ", Helvetica, sans-serif; font-weight: 400; padding-bottom:15px; padding-top:20px; line-height: 35px;" class="title_color"> <div style="padding:20px; line-height: 22px"> Prezado(a) [OPERADORDOEMAIL]</div> </td> </tr> <tr> <td align="left" class="title_color" style="color: #848999; font-size: 14px; font-family: " Questrial ", sans-serif; mso-line-height-rule: exactly; line-height: 24px; padding-bottom:15px;"> <div style="line-height: 24px;"> <p>O [OPERADOR] criou uma nova tarefa para você [RELACIONAMENTO] &nbsp <b> [NUMEROTICKETRELACIONADO]</b><br> <br> Segue os dados da Tarefa: <ul> <li> <p><b>Assunto:</b> [ASSUNTO]</p> </li> <li> <p><b>Parceiro:</b> [PARCEIRO]</p> </li> <li> <p><b>Data da Tarefa:</b> [DATACOMPROMISSO]</p> </li> <li> <p><b>Data de Vencimento:</b> [DATAVENCIMENTO]</p> </li> <li> <p><b>Classificação:</b> [CLASSIFICACAO]</p> </li> <li> <p><b>Descrição:</b> [DESCRICAO]</p> </li> </ul> </p> <br> </div> </td> </tr> <tr> <td height="10" style="font-size: 10px; line-height: 10px;">&nbsp;</td> </tr> </tbody> </table> </td> </tr> </tbody> </table> </td> </tr> </tbody> </table>';

        $template = strtr($template, array('[OPERADORDOEMAIL]'              => $row["NMOPERREAL"] , 
                                           '[OPERADOR]'                     => $row["OPERADORDOLOGADO"],
                                           '[RELACIONAMENTO]'               => $row["DSTIPO"],
                                           '[NUMEROTICKETRELACIONADO]'      => $row["NUMEROTICKETRELACIONADO"],
                                           '[ASSUNTO]'                      => $row["DSFILACONTATO"],
                                           '[PARCEIRO]'                     => $row["NMPARCNEGOCIO"],
                                           '[DATACOMPROMISSO]'              => $row["DTPLANFILACONTA"],
                                           '[DATAVENCIMENTO]'               => $row["DTVENCFILACONTA"],
                                           '[CLASSIFICACAO]'                => $row["DSCLASSIFICATAREFA"],
                                           '[DESCRICAO]'                    => $row["DSDETEFILACONTA"]));
        //Rotina de enviar email                                    
        $this->emailService->enviarEmailCompromisso('EMAILGENERICO', $parametrosEmail['to']['email'], $parametrosEmail['subject'], array('template' => $template), $parametrosEmail['from'], $parametrosEmail['to']['name'], null, null, null);
        
    }
    
}