<?php

namespace Teknisa\CRM\Service;

use Teknisa\CRM\Factory\CRMAssistentesFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Model\Util\NovoCodigo;

class CRMAssistentesService {
    protected $assistFactory;
    protected $environment;
    protected $instanceManager;
    
    public function __construct(Environment $environment, CRMAssistentesFactory $assistFactory) {
        $this->assistFactory = $assistFactory;
        $this->environment   = $environment;
        $this->instanceManager = \Zeedhi\Framework\DependencyInjection\InstanceManager::getInstance();
    }
    
    public function saveNewAssist($row, $nroperassist) {
        $nrorg         = $this->environment->getNrOrgTrab();
        $nrAssistencia = $this->getAssistenciaNumber($row["NROPERPRINCIPAL"],
            $nroperassist, $nrorg);
        
        // Verifica se essa assistência já existe no sistema
        if(is_null($nrAssistencia)) {
            $nrAssistencia = intval(NovoCodigo::geraCodigo($nrorg, "CRM_ASSISTENCIA",
                1, 10, false, true));
                
            $params = array(
                "NROPERPRINCIPAL" => $row["NROPERPRINCIPAL"],
                "NROPERASSIST"    => $nroperassist,
                "NRASSISTENCIA"   => $nrAssistencia
            );
            
            $this->assistFactory->saveNewAssist($params);
        } else {
            $this->activateAssist($nrAssistencia);
        }
        
        return $nrAssistencia;
    }
    
    public function getAssistenciaNumber($nroperprincipal, $nroperassist, $nrorg) {
        $params = array(
            "NROPERPRINCIPAL" => $nroperprincipal,
            "NROPERASSIST"    => $nroperassist,
            "NRORG"           => $nrorg
        );
        
        $result = $this->assistFactory->getAssistenciaNumber($params);
        
        $nrAssistencia = isset($result[0]) ?
            $result[0]["NRASSISTENCIA"] : null;
            
        return $nrAssistencia;
    }
    
    public function activateAssist($nrAssistencia) {
        $nrorg      = $this->environment->getNrOrgTrab();
        $cdoperador = $this->environment->getCdOperador();
        $params     = array(
            "NRASSISTENCIA" => $nrAssistencia,
            "CDOPERADOR"    => $cdoperador,
            "NRORG"         => $nrorg
        );
        
        $this->assistFactory->activateAssist($params);
    }
    
    public function removeAssist($nrassistencia) {
        $nrorg      = $this->environment->getNrOrgTrab();
        $nrorgOper  = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        
        $params = array(
            "NRASSISTENCIA" => $nrassistencia,
            "NRORG"         => $nrorg,
            "NRORGOPER"     => $nrorgOper,
            "CDOPERADOR"    => $cdoperador
        );
        
        $this->assistFactory->removeAssist($params);
    }
    
    public function checkIfCanEditOrEvolParc($row) {
        $parcService = $this->instanceManager->getService('Teknisa\CRM\Service\ParceiroNegocioService');
        
        $cdoperador = $this->environment->getCdOperador();
        $nrorg      = $this->environment->getNrOrgTrab();
        $nrparcOper = $parcService->getOperNrParcNegocio($cdoperador, $nrorg);
        
        $params = array(
            "NRPARCOPER"     => $nrparcOper,
            "NRPARCNEGOCIO"  => $row['NRPARCNEGOCIO'],
            "NRORG"          => $nrorg,
            "CDOPERADOR"     => $cdoperador,
            "CRM_NRORGTRAB"  => $row['CRM_NRORGTRAB']
        );
        
        $result = $this->assistFactory->checkIfCanEditOrEvolParc($params);

        return $result[0]["IDCANEDIT"] === 'S';
    }
    
    public function checkParamEditParcIsActive() {
        $nrorg = $this->environment->getNrOrgTrab();
        
        $params = array(
            "NRORG" => $nrorg
        );
        
        $result = $this->assistFactory->checkParamEditParcIsActive($params);
        
        return $result[0]["IDASSISTAPENAS"] === 'S';
    }
}