function CRM_Cliente_Controller(AbaInterlocutorController, ABAEnderecoParceiroController, ABALogotipoParceiroController, PartnerInfosModalController, ScreenService, Utilities, templateManager, General, restEngine, CRM_Utilities, ABEvolucaoController, Messages, evolutionTabController, ZhFilterPreferences, CRM_ParceiroNegocio_Service, ZHPromise) {
    var self = this;
    /**
     * Executa as funções necessárias no evento
     * "WidgetOnEnterOnce" da widget de prospect.
     * 
     * @param {object} widget widget de prospect
     * ("gridProspect").
    */
    this.widgetOnEnterOnce = function(widget, fieldsToApply) {
        
        var filterRow = {};
        var wdgt = templateManager.container.getWidget('gridCliente');
        
        if((typeof templateManager !== 'undefined') && templateManager.LOGGEDOPERATOR){
            filterRow.CDOPERRESPONSAVEL = [templateManager.LOGGEDOPERATOR.CDOPERADOR];
            
            if(widget.name === 'gridCliente' )
                CRM_Utilities.openFilterOnEnter(widget, filterRow, fieldsToApply);
            else{
                widget.dataSource.data = wdgt.dataSource.data;
                widget.appliedFilter = wdgt.appliedFilter;
            }
        }
        
        AbaInterlocutorController.setInterlocutorWidgetOnActiveWidget(widget, 3);
        ABAEnderecoParceiroController.setAddressWidgetOnActiveWidget(widget, 2);
        PartnerInfosModalController.setModalWidgetOnActiveWidget(widget, 'NRPARCNEGOCIO');
        ABALogotipoParceiroController.setLogoWidgetOnActiveWidget(widget, 8);
        
        //this.setResaleRules(widget); 
        //this.checkParamToAddProspect(widget);
        
    };
    
    this.saveClienteAndSetAudit = function(){
        var widget = templateManager.container.getActiveWidget();
        widget.currentRow.NRINSJURCLIE = widget.currentRow.NRINSJURCLIE.toString().replace(/[^0-9]/g,'');
        widget.currentRow.CDOPERADOR = templateManager.LOGGEDOPERATOR.CDOPERADOR;
        widget.currentRow.CRM_NRORGTRAB = getLocalVar('CRM_NRORGTRABALHO');
        this.setAuditInfo(widget);
        
        if(widget.isValid()) {
            CRM_Utilities.saveWidget(widget, false).then(function(response) {
                if(widget.currentRow.__is_new) {
                    widget.currentRow.NRPARCNEGOCIO = response.dataset.DADOS.NRPARCNEGOCIO;
                }
                
                this.updateEnderecoCliente(widget).then(function() {
                    widget.reload();
                }).catch(function(error) {
                    CRM_Utilities.showErrorMessage(error);
                    widget.reload();
                });
                
                widget.currentRow.NRCONCORRPROSPECT = response.dataset.CONCORRENTE ? response.dataset.CONCORRENTE.NRCONCORRPROSPECT : widget.currentRow.NRCONCORRPROSPECT;
                
                widget.view();
            }.bind(this));   
        }
	};
	
	this.setAuditInfo = function(widget){
        var currentRow = widget.currentRow;
        
        if(widget.currentRow.__is_new) {
            currentRow.DTINCLUSAO = self.momentNow();
            currentRow.CDOPERINCLUSAO = templateManager.LOGGEDOPERATOR.CDOPERADOR;
            currentRow.CDOPERULTATU = templateManager.LOGGEDOPERATOR.CDOPERADOR;
            currentRow.NMOPERULTATU = templateManager.LOGGEDOPERATOR.NMOPERADOR; 
            currentRow.NRORGULTATU = currentRow.NRORG;
        }else{
            currentRow.DTULTATU = self.momentNow();
            currentRow.CDOPERULTATU = templateManager.LOGGEDOPERATOR.CDOPERADOR;
            currentRow.NMOPERULTATU = templateManager.LOGGEDOPERATOR.NMOPERADOR; 
            currentRow.NRORGULTATU = currentRow.NRORG;
        }
    };
    
    this.momentNow = function(){
        return moment(new Date()).format('DD/MM/YYYY HH:mm:ss');
    };
    
    this.updateEnderecoCliente = function(widget) {
	    
	    // Promise que será resolvida quando o endereço for salvo
	    var deferred = ZHPromise.defer();
	    
	    var parametroRestEngine = {
                    'requestType':'Row',
                    'row': {'NRPARCNEGOCIO': widget.currentRow.NRPARCNEGOCIO, 'NRORG': widget.currentRow.NRORG}
                };
        
        restEngine.post('/crm_enderecoparc/findEndereco', parametroRestEngine,
            function(response) {
                var row = {
        	      NRPARCNEGOCIO: widget.currentRow.NRPARCNEGOCIO,
        	      CDTIPOENDERECO: 'PRINCIPAL',
        	      NRORG: widget.currentRow.NRORG,
        	      IDATIVO: 'S',
        	      CDPAIS: widget.currentRow.CDPAIS,
        	      SGESTADO: widget.currentRow.SGESTADO,
        	      CDMUNICIPIO: widget.currentRow.CDMUNICIPIO,
        	      CDBAIRRO: widget.currentRow.CDBAIRRO,
        	      CDLOGRADOURO: widget.currentRow.CDLOGRADOURO,
        	      NMBAIRROENDERECO: widget.currentRow.NMBAIRROENDERECO,
        	      DSCOMPLEENDERECO: widget.currentRow.DSCOMPLEENDERECO,
        	      NRCEPENDERECO: widget.currentRow.NRCEPENDERECO,
        	      DSENDERECO: widget.currentRow.DSENDERECO,
        	      NRIMOVELENDERECO: widget.currentRow.NRIMOVELENDERECO
        	    };
	    
	            if(response.dataset.columnsToReturn[0]) {
	                row.__is_new = false;
	                row.tipoEnderecoWasEdited = false;
	                row.NRENDERECOPARC = response.dataset.columnsToReturn[0].NRENDERECOPARC;
	            } else row.__is_new = true;
	            
        	    CRM_ParceiroNegocio_Service.salvarEndereco(row).then(function(successData) {
                    if (widget.isNewRow()) {
                        widget.currentRow.NRENDERECOPARC = successData.dataset.columnsToReturn.NRENDERECOPARC;
                        widget.currentRow.__is_new = false;
                    }
                    deferred.resolve();
                }, function(error) {
                    var errorMessage = 'Timeout';
                    if (error.data) {
                        errorMessage = error.data.error;
                    }
                    ScreenService.showMessage(errorMessage);
                }).catch(CRM_Utilities.showErrorMessage);
            }, undefined, 
            function(error) {
                console.log(error);
            }, null, 3000000
        );
    
        
        return deferred;
	};
    
    this.actionEvolutionNewRow = function(widName){
            
        this.closeActionsPopup().then(function(){
            var widget = templateManager.container.getWidget(widName);
            
            this.activateWidget(widget).then(function(){
                
                setTimeout(function(){
                    this.evolucaoNewRow();
                }.bind(this),100);
                
            }.bind(this));
            
        }.bind(this));
    };
    
    this.activateWidget = function(widget){
        var deferred = ZHPromise.defer();
        widget.activate();
        deferred.resolve();
        return deferred;
    };
    
    /**
     * Inicia o mvc para realizar um insert de tarefas
     * na widget de Evolução
    */
    this.evolucaoNewRow = function() {
            
        var widget = templateManager.container.getWidget("evolucao");
        
        
        General.widgetNewRow(widget);
        
        var currentRow = widget.currentRow;
        var loggedOperatorInfos = CRM_Utilities.getLoggedOperatorInfos();

        currentRow.DTHREVOLCONT = (currentRow.DTHREVOLCONT)? currentRow.DTHREVOLCONT : moment(new Date()).format('DD/MM/YYYY HH:mm');
        currentRow.NMOPERADOR = loggedOperatorInfos.NMOPERADOR;
        currentRow.CDOPEREVOL = loggedOperatorInfos.CDOPERADOR;
        currentRow.NRORG = loggedOperatorInfos.NRORG;
        
        ABEvolucaoController.setEvolDateChangePermission(widget);
        this.setOperatorNextTask(currentRow, loggedOperatorInfos);
        
        currentRow.DTINCLUSAO = self.momentNow();
        currentRow.NRSEQCONTATO = widget.getParent().currentRow.NRPARCNEGOCIO;

        currentRow.NRORG = loggedOperatorInfos.NRORG;
    };
    
    /**
     * Seta o operador para preparar a proxima tarefa
     * da widget de evolução
     * 
     * @param {object} currentRow pega a currentRow
     * da evolução
     * 
     * @param {object} loggedOperatorInfos objecto com
     * as informações do operador logado.
    */
    this.setOperatorNextTask = function(currentRow, loggedOperatorInfos){
        
        currentRow.NMOPERADORREAL = loggedOperatorInfos.NMOPERADOR;
        currentRow.CDOPERREAL = loggedOperatorInfos.CDOPERADOR;
        
    };
    
    this.closeActionsPopup = function() {
        var deferred = ZHPromise.defer();
        ScreenService.closePopup();
        deferred.resolve();
        return deferred;
    };
    
    this.evolucaoRowOnEnter = function(widget) {
        var prospectController = CRM_Utilities.getController('ger45000_Prospect_Controller');
        
        prospectController.setEditEvolButtonAction(widget, this.editEvolButtonDefaultCode, 'EDIT');
    };
    
    this.editEvolButtonDefaultCode = 
        `ger45000_Prospect_Controller.cleanTaskGroupIfInvisible(args.owner.widget, 'AGENDAR_TAREFA');
         crm00040_Lead_Controller.editEvolution(args.owner.widget);`;
         
    this.editClientActionOnClick = function(widget) {
        var nrParcNegocio = widget.currentRow.NRPARCNEGOCIO;
        var parceiroController = CRM_Utilities.getController('CRM_ParceiroNegocio_Controller');
        
        parceiroController.checkIfCanEditOrEvolParc(nrParcNegocio).then(canEdit => {
            if(canEdit) {
                General.widgetEdit(widget);
                widget.getField('NRINSJURCLIE').readOnly = false;
                widget.getField('NMRAZSOCCLIE').readOnly = false;
                parceiroController.setInscEstadualSelect(widget);
            } else {
                this.showMessageCantEditParc();
            }
        });
    };
    
    this.addEvolActionOnClick = function(widget) {
        var nrParcNegocio = widget.getParent().currentRow.NRPARCNEGOCIO;
        var prospectController = CRM_Utilities.getController('ger45000_Prospect_Controller');
        var parceiroController = CRM_Utilities.getController('CRM_ParceiroNegocio_Controller');
        
        parceiroController.checkIfCanEditOrEvolParc(nrParcNegocio).then(canEdit => {
            if(canEdit) {
                this.actionEvolutionNewRow('evolucao');
                prospectController.setNextTaskVisibility(widget, 'AGENDAR_TAREFA');
                
            } else {
                this.showMessageCantEditParc();
            }
        });
    };
    
    this.evolveActionOnClick = function(widget) {
        var nrParcNegocio = widget.currentRow.NRPARCNEGOCIO;
        var parceiroController = CRM_Utilities.getController('CRM_ParceiroNegocio_Controller');
        
        parceiroController.checkIfCanEditOrEvolParc(nrParcNegocio).then(canEdit => {
            if(canEdit) {
                this.actionEvolutionNewRow('evolucao'); 
            } else {
                this.showMessageCantEditParc();
            }
        });
    };
    
    this.showMessageCantEditParc = function() {
        var message = `Ação bloqueada!<br>
             Somente o operador responsável pelo cliente e seus assistentes podem
             editá-lo/evoluí-lo.`;
             
        ScreenService.showMessage(message);
    };
    
    this.clientNewRow = function(widget) {
        General.widgetNewRow(widget);
        
        widget.currentRow.NRORG = templateManager.LOGGEDOPERATOR.NRORG;    
        widget.currentRow.CDOPERRESPONSAVEL = templateManager.LOGGEDOPERATOR.CDOPERADOR;
        widget.currentRow.NMOPERRESPONSAVEL = templateManager.LOGGEDOPERATOR.NMOPERADOR;
        widget.currentRow.IDATIVO = 'S';
        widget.currentRow.IDPRIPUBPROS = '';
        widget.currentRow.IDPRIPUBPROS = '';
        widget.currentRow.CDMODODIVULG = '';
        widget.currentRow.CDATIVCLI = '';
        widget.currentRow.CDQUALIF = '';
        widget.currentRow.CDEXPEDIENTE = '';
        widget.currentRow.CDSEGMER = '';
        widget.currentRow.IDSITUPROS = '';
        widget.currentRow.DTNASCPROS = '';
        widget.currentRow.HRINIFUNCPROSP = '';
        widget.currentRow.HRFINFUNCPROSP = '';
        widget.currentRow.IDLIGEXTPROS = '';
        widget.currentRow.NRUNOPPROS = '';
        widget.currentRow.DSCONCORREPROSP = '';
        widget.currentRow.DTENCECONTRATU = '';
        widget.currentRow.DTREVPRECOPROSP = '';
        widget.currentRow.NRSEQTPATIVCLI = '';
        widget.getField('NRINSJURCLIE').readOnly = false;
        widget.getField('NMRAZSOCCLIE').readOnly = false;
        widget.currentRow.IDINSCRESTAD = "ISENTO";
        widget.getField('NRINSESTCLIE').value('ISENTO');
        widget.getField('NRINSESTCLIE').readOnly = true;
    };
    
    this.shootEventsAfterMoveRow = function() {
        var widget = templateManager.container.getWidget('gridCliente');
        var prospController = CRM_Utilities.getController('ger45000_Prospect_Controller');
        var parcNegController = CRM_Utilities.getController('CRM_ParceiroNegocio_Controller');
        
        parcNegController.setInscEstadualSelect(widget);
        prospController.getProspectNrSeqContato(widget);
    };
}

Configuration(function (ContextRegister) {
    ContextRegister.register("CRM_Cliente_Controller", CRM_Cliente_Controller);
});

