function crm30000000_Participantes_Compromisso_Controller(CRM_Utilities, templateManager, General, ScreenService, restEngine, Messages)
{
    
    /**
     * Filtra os resultados da widget de participantes
     * de acordo com o número de identificação do compromisso
     * marcado, e em seguida da um reload na widget.
    */
    this.insertParticipantsWidgetFilter = function(){
        
        var participantsWidget = templateManager.container.getWidget("WDGT_COMMITMENT_PARTICIPANTS");
        
        var widgetFilter = participantsWidget.dataSourceFilter;
        var calendarWidget = participantsWidget.parent.parent;
        var eventWidgetCurrentRow = calendarWidget.getEventsWidget().currentRow;
        
        var nrseqplanocupaIndex = CRM_Utilities.getFilterPosition(widgetFilter, "NRSEQPLANOCUPA");
        
        widgetFilter[nrseqplanocupaIndex].value = eventWidgetCurrentRow.NRSEQPLANOCUPA;
        
        participantsWidget.reload();
        
    };
    
    /**
     * Esconde o nome do operador responsável pelo
     * compromisso, para que ela não possa ser selecionado
     * como participante.
     * 
     * @param {object} field field de operador que receberá
     * o filtro.
    */
    this.hideResponsibleOperatorByFilter = function(field){
        
        var fieldFilter = field.dataSourceFilter;
        var commitmentWidgetCurrentRow = this.getCommitmentWidgetCurrentRow();
        
        var cdoperatorIndex = CRM_Utilities.getFilterPosition(fieldFilter, "CDOPERADOR");
        
        fieldFilter[cdoperatorIndex].value = commitmentWidgetCurrentRow.CDOPERADOR;
        
        field.reload();
        
    };
    
    /**
     * Filtra os resultados da fiels de participantes
     * para não trazer os participantes já cadastrados
     * no compromisso em caso.
     * 
     * @param {object} field field de participantes
     * que recebera o filtro.
    */
    this.setParticipantsFilter = function(field){
        
        var fieldFilter = field.dataSourceFilter;
        var commitmentWidgetCurrentRow = this.getCommitmentWidgetCurrentRow();
        
        var nrseqplanocupaIndex = CRM_Utilities.getFilterPosition(fieldFilter, "P_NRSEQPLANOCUPA");
        var nrparcnegocioFilterInddex = CRM_Utilities.getFilterPosition(fieldFilter, "P_NRPARCNEGOCIO");
        
        fieldFilter[nrseqplanocupaIndex].value = commitmentWidgetCurrentRow.NRSEQPLANOCUPA;
        fieldFilter[nrparcnegocioFilterInddex].value = commitmentWidgetCurrentRow.NRPARCNEGOCIO;
        
        field.reload();
        
    };

    /**
     * Salva participantes ao compromisso em caso.
     * 
     * @param {object} widget widget ativa onde está
     * sendo realizado o cadastro do participante do
     * compromisso.
    */
    this.saveCommitmentParticipants = function(widget){
        
        var currentRow = widget.currentRow;
        
        var commitmentParticipants = currentRow.CDOPERADORPART;
        var rows = [];
        
        commitmentParticipants.forEach(function(operator, participantIndex){
            
            rows.push(this.setCommitmentParticipantsValues(widget, participantIndex));
                
        }.bind(this)); 
        
        General.callRestEngine("product#/partplanocupa_operador/save", "DataSet", rows).then(function(response){
            if(response.dataset && response.dataset.error) {
                ScreenService.showMessage(response.dataset.error, 'ERROR');
                ScreenService.alertNotification('Nenhum participante adicionado foi notificado por falta dos dados na parametrização.', 5000);
            }
            ScreenService.closeSwipe();
            widget.reload();
            widget.list();
            
        });

    };
    
    /**
     * Cria uma cópia da currentRow da widget
     * recebida, define os valores do participante
     * na cópia e à retorna.
     * 
     * @param {object} widget widget ativa onde está
     * sendo realizado o cadastro do participante.
     * 
     * @param {int} participantIndex index do participante
     * nos arrays relacionados ao participantes selecionados
     * na field.
     * 
     * @return {obeject} currentRow cópia da currentRow 
     * da widget recebida como parâmetro, com os valores
     * do participante em caso.
    */
    this.setCommitmentParticipantsValues = function(widget, participantIndex){
        
        var currentRow = angular.copy(widget.currentRow);
        var commitmentWidgetCurrentRow = this.getCommitmentWidgetCurrentRow();
        var loggedOperatorInfos = CRM_Utilities.getLoggedOperatorInfos();
        
        if(currentRow.TIPO[participantIndex] === 'INTERLOCUTOR'){
            currentRow.NRPARCNEGOCIO = currentRow.CDOPERADORPART[participantIndex];  
            currentRow.CDOPERADOR = currentRow.CDOPERADORPART[participantIndex];  
        }else{
            currentRow.NRPARCNEGOCIO = currentRow.NRPARCNEGOCIO[participantIndex];  
            currentRow.CDOPERADOR = currentRow.CDOPERADORPART[participantIndex];
        }   
        
        currentRow.NRSEQPLANOCUPA = commitmentWidgetCurrentRow.NRSEQPLANOCUPA;
        currentRow.NRORG = currentRow.NRORGOPERADORPART[participantIndex];
        currentRow.DATACOMPROMISSO = commitmentWidgetCurrentRow.DTINIPLANOCUPA;
        currentRow.DATAFINAL = commitmentWidgetCurrentRow.DTFINPLANOCUPA;
        currentRow.REFERENCIA = commitmentWidgetCurrentRow.DSREF ? commitmentWidgetCurrentRow.DSREF : "";
        currentRow.MOTIVO = commitmentWidgetCurrentRow.NMMOTIEVOCON;
        currentRow.PARCEIRO = commitmentWidgetCurrentRow.NMPRINCIPALPARC;
        currentRow.OPERADOR = loggedOperatorInfos.NMOPERADOR;
        currentRow.PARTICIPANTE = currentRow.NMOPERADORPART[participantIndex];
        currentRow.DESCRICAO = commitmentWidgetCurrentRow.DSPLANOCUPA;
        currentRow.TIPOCOMPROMISSO = commitmentWidgetCurrentRow.TIPO;
        currentRow.CDINTEPLANOCUPA = "";
        
        return currentRow;
    };
    
    /**
     * Função para receber a currentRow no compromisso
     * em caso.
     * 
     * @return {object} currentRow currentRow da widget
     * do compromisso em caso.
    */
    this.getCommitmentWidgetCurrentRow = function(){
        
        var commitmentWidget = templateManager.container.getWidget("WDGT_NEW_COMMITMENT");
        
        return commitmentWidget.currentRow;
        
    };
    
    this.openPopupMensagem = function(args){
        
        var eventCurrentRow = templateManager.container.getWidget('WDGT_NEW_COMMITMENT').currentRow;

        if(!Boolean(eventCurrentRow.NOEDITABLE)){
            
            var widget = templateManager.container.getWidget('mensagens');
            widget.isVisible = true;
            ScreenService.openPopup(widget);
            
        } else {
            ScreenService.showMessage(Messages.IMPOSSIVEL_MANUSEAR_EVENTO(eventCurrentRow.BECAUSENOEDITABLE));
        }
    };
    
    this.notificarParticipantes = function(args){
        var popUp  = args.owner.widget;
        var widget = templateManager.container.getWidget("WDGT_COMMITMENT_PARTICIPANTS");
        
        if (popUp.isValid()) {
            widget.currentRow.__report_name = 'notificacao_compromisso';
            widget.currentRow.NRORGTRAB      = getLocalVar("CRM_NRORGTRAB");
            widget.currentRow.CDOPERADOR_LOG = getLocalVar("CRM_CDOPERADOR");
            widget.currentRow.NRSEQPLANOCUPA = widget.dataSourceFilter[0].value;
            
            var row = this.pegaParticipantesSalvos(widget);
            var saveData = Object.assign({}, row, {"MENSAGEM": popUp.currentRow});
             restEngine.post('/notificarCompromisso',{'requestType': 'Row','row': saveData})
             .then(function(data) {
                 if(data.dataset && data.dataset.error) {
                    ScreenService.showMessage(data.dataset.error, 'ERROR');
                    ScreenService.alertNotification('Nenhum participante foi notificado por falta dos dados na parametrização.', 5000);
                    ScreenService.closePopup(popUp);
                    widget.reload();
                } else {
                    var message = data.messages[(data.messages.length - 1)];
                    if(!Util.isEmptyOrBlank(data.messages)){
                        if (message.type === "M") {
                            ScreenService.showMessage('Participantes Notificados');
                            ScreenService.successNotification(message.message, 100000);
                            ScreenService.closePopup(popUp);
                            widget.reload();
                        } else {
                            ScreenService.showMessage('Nenhum participante cadastrado');    
                            ScreenService.closePopup(popUp);
                        }
                    } else {
                        ScreenService.showMessage('Falha ao notificar Participantes');
                    } 
                }
                }).catch(function(e) {
                    ScreenService.closePopup(popUp);
                    ScreenService.showMessage(e);
            });
        }
    };
    
    this.setTemplateInicial = function(args){
        var widget           = templateManager.container.getWidget("mensagens");
        var widgetCommitment = templateManager.container.getWidget("WDGT_NEW_COMMITMENT");
        var dataCompromisso  = widgetCommitment.currentRow.DTINIPLANOCUPA;
        widget.currentRow.DSMENSAGEM      = '<table border="0" width="100%" cellpadding="0" cellspacing="0" bgcolor="eeeeee" style="background-color: #eeeeee;"> <tbody> <tr> <td> <table border="0" align="center" width="590" cellpadding="0" cellspacing="0" bgcolor="0274BA" class="container590" style="background-color: #0274ba; text-align: center;"> <tbody> <tr> <td> <table border="0" align="center" width="540" cellpadding="0" cellspacing="0" class="container580"> <tbody> <tr> <td align="center" valign="middle"> <table border="0" align="middle" cellpadding="0" cellspacing="0" style="border-collapse:collapse; mso-table-lspace:0pt; mso-table-rspace:0pt;" class=""> <tbody> <tr> <td align="center" valign="middle"> <p style="color: #ffffff; font-size: 25px; padding:20px; font-family: " Questrial ", Helvetica, sans-serif; line-height: 25px; padding-top:45px;">ALERTA DE COMPROMISSO</p> <p style="color: #ffffff; font-size: 16px; font-family: "Questrial", Helvetica, sans-serif; line-height: 15px; padding-top:15px;"> [DATA] </p> <p style="color: #ffffff; font-size: 16px; font-family: "Questrial", Helvetica, sans-serif; line-height: 15px; padding-top:15px;">&nbsp;</p> <p style="color: #ffffff; font-size: 16px; font-family: " Questrial ", Helvetica, sans-serif; line-height: 15px; padding-top:15px;"> <br> </p> </td> </tr> </tbody> </table> </td> </tr> </tbody> </table> </td> </tr> </tbody> </table> </td> </tr> </tbody> </table> <table border="0" width="100%" cellpadding="0" cellspacing="0" bgcolor="eeeeee"> <tbody> <tr> <td align="center"> <table border="0" align="center" width="590" cellpadding="0" cellspacing="0" bgcolor="ffffff" class="container590 bg_color"> <tbody> <tr> <td> <table border="0" align="center" width="540" cellpadding="0" cellspacing="0" class="container580"> <tbody> <tr> <td align="left" style="color: #39434b; font-size: 20px; font-family: " Montserrat ", Helvetica, sans-serif; font-weight: 400; padding-bottom:15px; padding-top:20px; line-height: 35px;" class="title_color"> <div style="padding:20px; line-height: 22px"> Prezado(a) [PARTICIPANTE]</div> </td> </tr> <tr> <td align="left" class="title_color" style="color: #848999; font-size: 14px; font-family: " Questrial ", sans-serif; mso-line-height-rule: exactly; line-height: 24px; padding-bottom:15px;"> <div style="line-height: 24px;"> <p>Você está recebendo este email para alertá-lo sobre seu Compromisso no dia [DATA].</p> <br> </div> </td> </tr> <tr> <td height="10" style="font-size: 10px; line-height: 10px;">&nbsp;</td> </tr> </tbody> </table> </td> </tr> </tbody> </table> </td> </tr> </tbody> </table> ';
        widget.currentRow.DATACOMPROMISSO = dataCompromisso.replace(' ', ' as ');
        widget.reload();
    };
    
    //foi criada essa função pois na current row não vão todos os participantes
    this.pegaParticipantesSalvos = function(widget) {
        var row = [];
        
        if(Util.isEmptyOrBlank(widget.dataSource.data)) {
            row.NRSEQPLANOCUPA = templateManager.container.getWidget('WDGT_NEW_COMMITMENT').currentRow.NRSEQPLANOCUPA;
        }else {
            widget.dataSource.data.forEach(function(registro) {
                row.CDOPERADOR = []; row.CDOPERADORPART = []; row.DSEMAILOPER = []; row.NMOPERADOR = []; row.NRORG = [];
                row.NRPARCNEGOCIO = []; row.NRSEQPLANOCUPA = []; row.TIPO = [];
                
                row.CDOPERADOR.push(registro.CDOPERADOR);
                row.CDOPERADORPART.push(registro.CDOPERADORPART);
                row.DSEMAILOPER.push(registro.DSEMAILOPER);
                row.NMOPERADOR.push(registro.NMOPERADOR);
                row.NRORG.push(registro.NRORG);
                row.NRPARCNEGOCIO.push(registro.NRPARCNEGOCIO);
                row.NRSEQPLANOCUPA.push(registro.NRSEQPLANOCUPA);
                row.TIPO.push(registro.TIPO);
            });
        }
        
        return row;
    };
    
    this.interlocOnChange = function() {
        var widget = templateManager.container.getActiveWidget();
        var field = widget.getField('CDOPERADOR');
        var keys = field.value();
        var rows = field.selectWidget.getCheckedRows();
        field.widget.currentRow.NMOPERADORPART = [];
        field.widget.currentRow.NRORGOPERADORPART = [];
        field.widget.currentRow.NRPARCNEGOCIO = [];
        field.widget.currentRow.DSEMAILOPER = [];
        field.widget.currentRow.TIPO = [];
        
        rows.forEach(function(row) {
    		keys.forEach(function(key) {
    			if (row.CDOPERADOR == key) {
                    field.widget.currentRow.NMOPERADORPART.push(row.NMOPERADOR);
                    field.widget.currentRow.NRORGOPERADORPART.push(row.NRORG);
                    field.widget.currentRow.NRPARCNEGOCIO.push(row.NRPARCNEGOCIO);
                    field.widget.currentRow.DSEMAILOPER.push(row.DSEMAILOPER);
                    field.widget.currentRow.TIPO.push(row.TIPO);
    			}
    		});
    	});
    };
    
}

Configuration(function(ContextRegister) {
    ContextRegister.register('crm30000000_Participantes_Compromisso_Controller', crm30000000_Participantes_Compromisso_Controller);
});